/********************************************************************
*
*
*
*********************************************************************
* FileName:        BOARD.C
* Dependencies:    See INCLUDES section below
* Processor:       PIC16F886
* Compiler:        HITECH 9.6 STD (only)
* Company:         Microchip Technology, Inc.
*
* Software License Agreement:
*
* The software supplied herewith by Microchip Technology Incorporated
* (the "Company") for its PICmicro Microcontroller is intended and
* supplied to you, the Company's customer, for use solely and
* exclusively on Microchip PICmicro Microcontroller products. The
* software is owned by the Company and/or its supplier, and is
* protected under applicable copyright laws. All rights are reserved.
* Any use in violation of the foregoing restrictions may subject the
* user to criminal sanctions under applicable laws, as well as to
* civil liability for the breach of the terms and conditions of this
* license.
*
* THIS SOFTWARE IS PROVIDED IN AN "AS IS" CONDITION. NO WARRANTIES,
* WHETHER EXPRESS, IMPLIED OR STATUTORY, INCLUDING, BUT NOT LIMITED
* TO, IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
* PARTICULAR PURPOSE APPLY TO THIS SOFTWARE. THE COMPANY SHALL NOT,
* IN ANY CIRCUMSTANCES, BE LIABLE FOR SPECIAL, INCIDENTAL OR
* CONSEQUENTIAL DAMAGES, FOR ANY REASON WHATSOEVER.
*********************************************************************
* File Description: Board specific routines
*
* Change History:
* Author k.curtis   Date  2008      Comment
********************************************************************/


#include "htc.h"
#include "ssp.h"
#include "board.h"

void select_keypad(unsigned char channel)
{

	RB2 = 1;
											// select one of 4 pads (channel = 0 - 3)
	switch (channel)
		{ 	case 0: RB0 =0; RB1=0; RB2 = 0; break;   // 0 key
			case 1: RB0 =1; RB1=0; RB2 = 0; break;   // 1 key
			case 2: RB0 =0; RB1=1; RB2 = 0; break;   // 2 key
			case 3: RB0 =1; RB1=1; RB2 = 0; break;   // 3 key
			default: break;			//disable key
		}

}

void SelectRef(unsigned char ref)
{
	if (ref==0)	RB5 = 0;								// if ref =1 select pad as opposed to reference coil, else select coil
	else RB5 = 1;
}

void SetLED(unsigned char led)
{

	if (led==NUM_BTTNS) RA7 = 0;
	else RA7 = 1;

}

void Beep(unsigned char key)
{
	unsigned int k;

	CCP1CON = 0x00;				//disable 2MHz PWM
	CCPR1L  = 0x00;

	PR2 = 0x70 - ( key * 0x8);
	CCP2CON = 0b00001100;
	CCPR2L  = 0x38 - (key*0x04);

	T2CON = 0b00000101;			//TMR2 prescaler = 4, TMR2 on

	k = CLICK_LENGTH;
	while(--k!=0);

	T2CON = 0b00000000;			//TMR2 prescaler = 1, TMR2 off
	CCP2CON = 0x00;				//disable buzzer output
	CCPR2L  = 0x0;

	PR2 = 0;        			// 2MHz PWM rate
	CCP1CON = 0x0C;
	CCPR1L  = 0x00;

}

void InitPORT(void)
{
	// *********** PORTA SETUP ***************

	TRISA = 0x7F;	// all inputs

	ANSEL = 0x00;		//  no analog pins on PORTA

	PORTA = 0x80;	// clear PORTA

	// *********** PORTB SETUP ***************

	TRISB = 0xD0;	// b11000000
					// .. set RB0 as ouput
					// .. set RB1 as output
					// .. set RB2 as ouput
					// .. set RB3 as output

					// .. set RB5 as output

					// .. RB0 pin is for SEL_A
					// .. RB1 pin is for SEL_B
					// .. RB2 pin is for COL_0

					// .. RB5 pin is for REF_SEL
	ANSELH = 0x08; 	// analogue input pins on RB4 = Pad data

	PORTB = 0x04;	// Deselect Key

	// *********** PORTC SETUP **************

	TRISC = 0xFC;			// b11111100
	PORTC = 0x00;			// clear PORTC

}

void InitPeripheral(void)
{
	PWM1CON = 0;
	ECCPAS = 0;
	CM1CON0 =0;
	CM2CON0=0;
	PSTRCON=0x01;

	// ************ I2C communications.*****************

 	SSPInit();
	// ************ On-CPU ADC SETUP ***************

	ADCON1 = 0x80;		// Left justified

	ADCON0 = 0xAD;		// turn on convertor, select channel AN11, ADC clock div 32


	// ********** TIMER0 SETUP **************

//	T0CS = 1;		// select timer 0 clock input as external
//	T0SE = 0;		// select rising edge clocking
//	PSA = 1;		// assign prescaler to watchdog timer
//	PS2 = 1;		// set prescaler select bits to b101
//	PS1 = 0;		// .. this is a count divide by 32
//	PS0 = 1;
//
	// ********** TIMER1 SETUP **************
//
//	TMR1CS = 0;		// select timer 1 clock input as (processor clock / 4)
//	T1CKPS0 = 0;
//	T1CKPS1 = 0;		// prescale value of 1:1
//	T1OSCEN = 0;		// disable timer 1 oscillator driver
//	TMR1L = 0;		// reset the timer
//	TMR1H = 0;		// reset the timer
//	TMR1ON = 0;		// turn off the timer
//
	// ********** TIMER2 SETUP **************

	PR2 = 0;        	// 2MHz PWM rate

	CCP1CON = 0x2C;
	CCPR1L  = 0x00;

	TMR1IF = 0;
	T2CON = 0x00;
	TMR2ON = 0;

	TRISC &= 0xFB;

}

