/********************************************************************
*
*
*
*********************************************************************
* FileName:        BOARD.H
* Dependencies:    See INCLUDES section below
* Processor:       PIC16F886
* Compiler:        HITECH 9.6 STD (only)
* Company:         Microchip Technology, Inc.
*
* Software License Agreement:
*
* The software supplied herewith by Microchip Technology Incorporated
* (the "Company") for its PICmicro Microcontroller is intended and
* supplied to you, the Company's customer, for use solely and
* exclusively on Microchip PICmicro Microcontroller products. The
* software is owned by the Company and/or its supplier, and is
* protected under applicable copyright laws. All rights are reserved.
* Any use in violation of the foregoing restrictions may subject the
* user to criminal sanctions under applicable laws, as well as to
* civil liability for the breach of the terms and conditions of this
* license.
*
* THIS SOFTWARE IS PROVIDED IN AN "AS IS" CONDITION. NO WARRANTIES,
* WHETHER EXPRESS, IMPLIED OR STATUTORY, INCLUDING, BUT NOT LIMITED
* TO, IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
* PARTICULAR PURPOSE APPLY TO THIS SOFTWARE. THE COMPANY SHALL NOT,
* IN ANY CIRCUMSTANCES, BE LIABLE FOR SPECIAL, INCIDENTAL OR
* CONSEQUENTIAL DAMAGES, FOR ANY REASON WHATSOEVER.
*********************************************************************
* File Description: header file for board specific values
*
* Change History:
* Author k.curtis   Date 2008       Comment
********************************************************************/

#define NUM_BTTNS		4						// Number of capacitive buttons
#define SENSIBILITY 	0.03					// 0.01 to 0.1
#define DEVICE_ADDR		0x42					// Device's I2C Address

#define ADC_MASK 	0xFF

// Global Constants

#define CLICK_LENGTH		33333				// keyclick duration -  166 is 1ms

#define RX_DELAY			1600				// RX output settling delay (approx. 1.8 mS per)

#define REF_DELAY			1600				//  Reference settling delay (approx. 1.8 mS per)

#define WAIT_10ms			3333				// delay time for 10ms (approx. 3uS per)
#define WAIT_30ms			10000				// delay time for 30ms (approx. 3uS per)
#define WAIT_100ms			16666				// delay time for 100ms (approx. 3uS per)


// Functions
void restart_delay(void);

void measure_pad(unsigned char channel);

unsigned int adc(void);


//***********************************************************************************
//	SelectRef(unsigned char ref)
//		Select reference inductor or keypad inductor for measurements
//		Input - unsigned char ref
//					ref = 0 - select reference inductor
//					ref = 1 - select keypad inductor
//		Output - none
//***********************************************************************************
void SelectRef(unsigned char ref);


//***********************************************************************************
//	select_keypad(unsigned char channel)
//		Activate specific key for measurements
//		Input - unsigned char channel
//					channel = 0 to (NUM_BTTNS-1) - activate specific key inductor
//							= other values - deselect keys
//		Output - none
//***********************************************************************************
void select_keypad(unsigned char channel);

//***********************************************************************************
//	SetLED(unsigned char channel)
//		Turn on LED assigned to channel
//		Input - unsigned char channel
//					channel = 0 to (NUM_BTTNS-1) - turn on specific LED
//							= other values - turn off all LED's
//***********************************************************************************
void SetLED(unsigned char led);

void Beep(unsigned char key);

//***********************************************************************************
//	InitPORT()
//		Initializes and configures IO pins
//		Input - none
//		Output - none
//***********************************************************************************
void InitPORT(void);

//***********************************************************************************
//	InitPeripheral()
//		Initializes and configures PIC peripheral
//				- TIMER2 for PWM generation
//				- select ADC channel for measurements
//				- init SSP module for I2C comunication
//		Input - none
//		Output - none
//***********************************************************************************
void InitPeripheral(void);
